aind\_behavior\_curriculum.curriculum.PolicyGraph
=================================================

.. currentmodule:: aind_behavior_curriculum.curriculum

.. autoclass:: PolicyGraph
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PolicyGraph.__init__
      ~PolicyGraph.add_node
      ~PolicyGraph.add_transition
      ~PolicyGraph.construct
      ~PolicyGraph.copy
      ~PolicyGraph.dict
      ~PolicyGraph.from_orm
      ~PolicyGraph.json
      ~PolicyGraph.model_construct
      ~PolicyGraph.model_copy
      ~PolicyGraph.model_dump
      ~PolicyGraph.model_dump_json
      ~PolicyGraph.model_json_schema
      ~PolicyGraph.model_parametrized_name
      ~PolicyGraph.model_post_init
      ~PolicyGraph.model_rebuild
      ~PolicyGraph.model_validate
      ~PolicyGraph.model_validate_json
      ~PolicyGraph.model_validate_strings
      ~PolicyGraph.parse_file
      ~PolicyGraph.parse_obj
      ~PolicyGraph.parse_raw
      ~PolicyGraph.remove_node
      ~PolicyGraph.remove_node_transition
      ~PolicyGraph.schema
      ~PolicyGraph.schema_json
      ~PolicyGraph.see_node_transitions
      ~PolicyGraph.see_nodes
      ~PolicyGraph.set_transition_priority
      ~PolicyGraph.update_forward_refs
      ~PolicyGraph.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PolicyGraph.model_computed_fields
      ~PolicyGraph.model_config
      ~PolicyGraph.model_extra
      ~PolicyGraph.model_fields
      ~PolicyGraph.model_fields_set
      ~PolicyGraph.nodes
      ~PolicyGraph.graph
   
   